%  ARMAX.m
%  -------
%  Creates and validates the linear ARMAX model structure.        
%  Written by : Oskar Gross
%  LastEditDate  : May, 24, 2009

%% Create ARMAX structure with lag-space of 2
% Network definition, where the first row is hidden layer and second row is
% the output layer

% Prepare the data first
[u_test u_train u_valid y_test y_train y_valid] = PrepareData();
lag = 4;
NetDef = ['L'; 'L'];

trparms = settrain;

% Initialize weights
W1 = [];
W2 = [];

% The lag structure
%  NN      : NN=[na nb nc nk].
%            na = # of past outputs used for determining the prediction
%            nb = # of past inputs
%            nc = # of past residuals (= order of C)
%            nk = time delay (usually 1)

NN = [4 4 4 1];

[W1,W2,PI_vector,iteration,lambda]=nnarmax2(NetDef,NN,W1,W2,trparms,y_train,u_train);

[Yhat,NSSE]=nnvalid('nnarmax2',NetDef,NN,W1,W2,y_test,u_test);

[meanError] = meanSquaredError(y_test,Yhat,4);

%% Analyze k-predictions performance
Yhat=kpredict('nnarmax2',NetDef,NN,1,W1,W2,y_valid,u_valid);

[meanErrorPredict] = meanSquaredError(y_valid,Yhat,4);

Yhat=kpredict('nnarmax2',NetDef,NN,3,W1,W2,y_valid,u_valid);

[meanErrorPredict3] = meanSquaredError(y_valid,Yhat,4+2);

Yhat=kpredict('nnarmax2',NetDef,NN,20,W1,W2,y_valid,u_valid);

[meanErrorPredict20] = meanSquaredError(y_valid,Yhat,4+19);