%  ADDSAMPLESTOREGRESSIONMATRIX
%  -----
%          Makes possible to add time samples to regression matrix.
%
%  CALL:
%        [PHI,Y,Index] = AddSamplesToRegressionMatrix(oldPHI,oldY,oldIndex,NN, U,Y,Struct)
%
% INPUTS:
%  oldPHI   : Old regression matrix
%  oldY     : Old output signals
%  OldIndex : Old index of the regression matrix
%  U        : input signals
%  Y        : output signals
%  Struct   : model structure (nnarx, nnoe, nnarmax, nnssif)
%  NN       : NN=[na nb nk]'
%  nx       : Use in case of NNSSIF model
%
% OUTPUTS:
% PHI       : new regression matrix
% Y         : new output signals
% Index     : defines the sample addition places
%
%  Programmed by: Oskar Gross, University of Tartu
%  LastEditDate  : June 1, 2009

function [PHI,Y,Index] = AddSamplesToRegressionMatrix(oldPHI, oldY, oldIndex, NN, U,Y, Struct, nx)

if(strcmp(Struct,'nnarx') == 1)
    N  = length(Y);
    na = NN(1);
    if length(NN)==1
      nb = 0;                          % nnar model
      nk = 0;
      nu = 0; 
    else
      [nu,N]      = size(U); 
      nb = NN(2:1+nu);                 % nnarx model
      nk = NN(2+nu:1+2*nu);
    end

    nmax        = max([na,nb+nk-1]);
    nab         = na+sum(nb);

    lenPHI = length(oldPHI);
    PHI = zeros(nab,N-nmax);
    jj  = nmax+1:N;
    for k = 1:na, PHI(k,:)    = Y(jj-k); end
    index = na;
    for kk = 1:nu,
      for k = 1:nb(kk), PHI(k+index,:) = U(kk,jj-k-nk(kk)+1); end
      index = index + nb(kk);
    end

    Index = [oldIndex (lenPHI+1)];
    Y = [oldY Y(nmax+1:N)];
    PHI = [oldPHI PHI];
end

if(strcmp(Struct,'nnarmax') == 1)
    
    na = NN(1);
    [nu,Ndat]= size(U); 
    nb     = NN(2:1+nu);
    nc     = NN(2+nu);
    nk     = NN(2+nu+1:2+2*nu);
    
    nab = na + sum(nb);
    nmax     = max([na,nb+nk-1,nc]);
    N        = Ndat - nmax;
    nabc     = nab+nc;      
    
    PHI = zeros(nabc,N);
    jj  = nmax+1:Ndat;
    for k = 1:na, PHI(k,:)    = Y(jj-k); end
    index5 = na;
    for kk = 1:nu,
      for k = 1:nb(kk), PHI(k+index5,:) = U(kk,jj-k-nk(kk)+1); end
      index5 = index5 + nb(kk);
    end
    lastIndex = oldIndex(length(oldIndex));
    phiLen = length(PHI);
    Index = [oldIndex lastIndex+phiLen+1];
    Y = Y(nmax+1:Ndat);
    Y = [oldY Y];
    PHI_aug = [PHI;ones(1,N)];              % Augment PHI with a row containg one
    PHI = [oldPHI PHI_aug];
end

if(strcmp(Struct,'nnoe') == 1)
    na = NN(1);
    [nu,Ndat]= size(U); 
    nb     = NN(2:1+nu);
    nk     = NN(1+nu+1:2+2*nu);
    nmax   = max([na nb+nk-1]);
    nab      = na+sum(nb);
    N        = Ndat - nmax;
    
    PHI = zeros(nab,N);
    jj  = nmax+1:Ndat;
    for k = 1:na, PHI(k,:)    = Y(jj-k); end
    index5 = na;
    for kk = 1:nu,
      for k = 1:nb(kk), PHI(k+index5,:) = U(kk,jj-k-nk(kk)+1); end
      index5 = index5 + nb(kk);
    end
    Y       = Y(nmax+1:Ndat);               % Extract the 'target' part of Y
    
    lastIndex = oldIndex(length(oldIndex));
    phiLen = length(PHI);
    Index = [oldIndex lastIndex+phiLen+1];
    Y = [oldY Y];
    PHI_aug = [PHI;ones(1,N)];              % Augment PHI with a row containg one
    PHI = [oldPHI PHI_aug];
    
end
% Not working yet
if(strcmp(Struct, 'nnssif') == 1)
    [ny,Ndat]= size(Y);                     % # of outputs and # of data
    [nu,Ndat]= size(U);                     % # of inputs 
    N        = Ndat - 1; 
    PHI(NN+1:NN+nu,:) = U(:,1:N);
    PHI_aug = [PHI;ones(1,N)];                % Augment PHI with a row containing ones
    Y       = Y(:,2:Ndat);                    % Extract the 'target' part of
    
    phiLen = length(PHI);
    lastIndex = oldIndex(length(oldIndex));
    Index = [oldIndex lastIndex+phiLen+1];
    Y = [oldY Y];
    PHI = [oldPHI PHI_aug];
end
    
end